pub struct RefResolver { /* private fields */ }Implementations
Sourceimpl RefResolver
impl RefResolver
Sourcepub fn new(elements: &IndexMap<String, Element>) -> Self
pub fn new(elements: &IndexMap<String, Element>) -> Self
Build a resolver from a parsed elements map (as produced by parser::parse_file).
Sourcepub fn to_human(&self, epoch_ref: &str) -> Option<&str>
pub fn to_human(&self, epoch_ref: &str) -> Option<&str>
Return the human ref for an epoch ref, or None if not mapped.